Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Duet3D/RepRapFirmware.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/SBC/SbcInterface.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/SBC/SbcInterface.cpp b/src/SBC/SbcInterface.cpp
index 766def66..592cb16b 100644
--- a/src/SBC/SbcInterface.cpp
+++ b/src/SBC/SbcInterface.cpp
@@ -443,7 +443,7 @@ void SbcInterface::ExchangeData() noexcept
break;
}
// Lock movement and wait for standstill
case SbcRequest::LockMovementAndWaitForStandstill:
{
const GCodeChannel channel = transfer.ReadCodeChannel();
@@ -451,7 +451,7 @@ void SbcInterface::ExchangeData() noexcept
{
GCodeBuffer * const gb = reprap.GetGCodes().GetGCodeBuffer(channel);
MutexLocker locker(gb->mutex, SbcYieldTimeout);
- if (locker.IsAcquired() && reprap.GetGCodes().LockCurrentMovementSystemAndWaitForStandstill(*gb))
+ if (locker.IsAcquired() && reprap.GetGCodes().LockAllMovementSystemsAndWaitForStandstill(*gb))
{
transfer.WriteLocked(channel);
}
@@ -443,7 +443,7 @@ void SbcInterface::ExchangeData() noexcept
break;
}
- // Lock movement and wait for standstill
+ // Lock movement and wait for standstill. Currently this is used only by M505, so we lock all movement systems.
case SbcRequest::LockMovementAndWaitForStandstill:
{